
# Slot: node_types_number


The number of the unique node types. This will be used in order to allocate the correct size for the data structure.

URI: [https://w3id.org/neat/ensmallenRunConfig__node_types_number](https://w3id.org/neat/ensmallenRunConfig__node_types_number)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Integer](types/Integer.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
